#pragma once

#include <vector>

#include "glm/glm.hpp"

typedef std::vector<float> Vector6;

class Orbit
{
public:
    Orbit();
    ~Orbit() = default; 

    float getSemiMajorAxis() const;
    float getEccentricity() const;
    float getInclination() const;
    float getArgumentOfPeriapsis() const;
    float getLongitudeOfAscendingNode() const;

    void setSemiMajorAxis(float semiMajorAxis);
    void setEccentricity(float eccentricity);
    void setInclination(float inclination);
    void setArgumentOfPeriapsis(float argumentOfPeriapsis);
    void setLongitudeOfAscendingNode(float longitudeOfAscendingNode);

    // TODO: meanAnomaly in all these arguments actually means eccentricMeanAnomaly,
    // will have to change that when adding non-ellipctical orbits - don't get confused!
    glm::vec3 getPosition(const float meanAnomaly) const;
    glm::vec3 getTangent(const float meanAnomaly) const;
    glm::mat4 getLookAlongMatrix(const float meanAnomaly) const;

private:
    Vector6 _keplerianElements;

    const float getEccentricAnomaly(const float meanAnomaly) const;
    const float getTrueAnomaly(const float meanAnomaly) const;
    const Vector6 getCartesianCoordinates(const float meanAnomaly) const;
};
